# psychopy-crs

Extension package for PsychoPy which adds support for various hardware devices by 
[Cambridge Research Systems Ltd.](https://www.crsltd.com/). 

## Supported Devices

Installing this package alongside PsychoPy will enable support for the following devices:

* Bits# and Bits++ Stimulus Processors
* Display++ and Display++ Touch LCD Monitors
* ColorCAL Colorimeters
    
## Installing

Install this package with the following shell command:: 

    pip install psychopy-crs

You may also use PsychoPy's builtin package manager to install this package.

## Usage

Once the package is installed, PsychoPy will automatically load it when started and make objects available within the
`psychopy.hardware.crs` namespace.
